wisp
 
(Arne Babenhauserheide)
2014-01-04: renamed wisp.el back to wisp-mode.el - thanks to Steve Purcell and support-scheme-macro-paren-quoting

renamed wisp.el back to wisp-mode.el - thanks to Steve Purcell and Kris Jenkins for resolving the name clash!

diff --git a/wisp.el b/wisp-mode.el
rename from wisp.el
rename to wisp-mode.el
--- a/wisp.el
+++ b/wisp-mode.el
@@ -1,4 +1,4 @@
 ;;; wisp.el --- Tools for wisp: the Whitespace-to-Lisp preprocessor
 
 ;; Copyright (C) 2013  Arne Babenhauserheide <arne_bab@web.de>
 
@@ -21,10 +21,10 @@
 
 ;;; Commentary:
 
 ;; To use, add wisp.el to your emacs lisp path and add the following
 ;; to your ~/.emacs or ~/.emacs.d/init.el
 ;; 
-;; (require 'wisp)
+;; (require 'wisp-mode)
 ;; 
 ;; For details on wisp, see 
 ;; http://draketo.de/light/english/wisp-lisp-indentation-preprocessor
@@ -102,5 +102,5 @@
 
                         
 
-(provide 'wisp)
-;;; wisp.el ends here
+(provide 'wisp-mode)
+;;; wisp-mode.el ends here
@@ -1,4 +1,4 @@
-;;; wisp.el --- Tools for wisp: the Whitespace-to-Lisp preprocessor
+;;; wisp-mode.el --- Tools for wisp: the Whitespace-to-Lisp preprocessor
 
 ;; Copyright (C) 2013  Arne Babenhauserheide <arne_bab@web.de>
@@ -21,10 +21,10 @@
 ;;; Commentary:
 
-;; To use, add wisp.el to your emacs lisp path and add the following
+;; To use, add wisp-mode.el to your emacs lisp path and add the following
 ;; to your ~/.emacs or ~/.emacs.d/init.el
 ;; 